==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/WeightedDirectedEdge.h <==
// class soot.jimple.toolkits.annotation.arraycheck.WeightedDirectedEdge

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 556814ff5505c22e soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$_init$a804effe5455d5e8(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs {
	struct _jc_java_lang_Object$object	*from;
	struct _jc_java_lang_Object$object	*to;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs {
	jint	weight;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/WeightedDirectedEdge.h <==
// class soot.jimple.toolkits.annotation.arraycheck.WeightedDirectedEdge

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 556814ff5505c22e soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$_init$a804effe5455d5e8(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vmethods	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs {
	struct _jc_java_lang_Object$object	*from;
	struct _jc_java_lang_Object$object	*to;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_refs	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs {
	jint	weight;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedEdge_H_ */
